# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.analytical_orbital_transfer_request import AnalyticalOrbitalTransferRequest

class TestAnalyticalOrbitalTransferRequest(unittest.TestCase):
    """AnalyticalOrbitalTransferRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalyticalOrbitalTransferRequest:
        """Test AnalyticalOrbitalTransferRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalyticalOrbitalTransferRequest`
        """
        model = AnalyticalOrbitalTransferRequest()
        if include_optional:
            return AnalyticalOrbitalTransferRequest(
                initial_orbit = orbital_transfer.models.orbit.Orbit(
                    inclination = 1.337, 
                    sma = 1.337, 
                    eccentricity = 1.337, 
                    parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(), 
                    advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                        orbit_date = '', 
                        ascending_node_type = 'RAAN', 
                        raan = 1.337, 
                        mltan = 1.337, 
                        anomaly = 1.337, 
                        anomaly_type = 'TRUE', 
                        orbital_element_type = 'MEAN', 
                        perigee_argument = 1.337, ), ),
                final_orbit = orbital_transfer.models.orbit.Orbit(
                    inclination = 1.337, 
                    sma = 1.337, 
                    eccentricity = 1.337, 
                    parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(), 
                    advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                        orbit_date = '', 
                        ascending_node_type = 'RAAN', 
                        raan = 1.337, 
                        mltan = 1.337, 
                        anomaly = 1.337, 
                        anomaly_type = 'TRUE', 
                        orbital_element_type = 'MEAN', 
                        perigee_argument = 1.337, ), ),
                spacecraft = orbital_transfer.models.parametric_spacecraft.ParametricSpacecraft(
                    platform_mass = 1.337, 
                    orbital_average_power = 1.337, 
                    custom_orbital_duty_cycle = True, 
                    orbital_duty_cycle = 1.337, 
                    drag_area = 1.337, 
                    drag_coefficient = 1.337, 
                    solar_radiation_pressure_center_in_spacecraft_frame_x = 1.337, 
                    solar_radiation_pressure_center_in_spacecraft_frame_y = 1.337, 
                    solar_radiation_pressure_center_in_spacecraft_frame_z = 1.337, 
                    inertia_xx = 1.337, 
                    inertia_xy = 1.337, 
                    inertia_xz = 1.337, 
                    inertia_yy = 1.337, 
                    inertia_yz = 1.337, 
                    inertia_zz = 1.337, 
                    inertia_zx = 1.337, 
                    inertia_zy = 1.337, 
                    inertia_yx = 1.337, 
                    max_angular_rate = 1.337, 
                    min_angular_rate = 1.337, 
                    thruster = orbital_transfer.models.parametric_propulsion_system.ParametricPropulsionSystem(
                        total_impulse = 1.337, 
                        position_in_spacecraft_frame_x = 1.337, 
                        position_in_spacecraft_frame_y = 1.337, 
                        position_in_spacecraft_frame_z = 1.337, 
                        direction_in_spacecraft_frame_x = 1.337, 
                        direction_in_spacecraft_frame_y = 1.337, 
                        direction_in_spacecraft_frame_z = 1.337, 
                        thrust = 1.337, 
                        isp = 1.337, 
                        power = 1.337, 
                        propellant_mass = 1.337, 
                        total_mass = 1.337, 
                        standby_power = 1.337, 
                        warm_up_power = 1.337, 
                        warm_up_duration = 1.337, 
                        propellant_capacity_choice = 'PROPELLANT', ), ),
                drag_perturbation_enabled = True
            )
        else:
            return AnalyticalOrbitalTransferRequest(
        )
        """

    def testAnalyticalOrbitalTransferRequest(self):
        """Test AnalyticalOrbitalTransferRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from orbital_transfer.models.propulsion_system import PropulsionSystem
from orbital_transfer.models.spacecraft_geometry import SpacecraftGeometry
from typing import Optional, Set
from typing_extensions import Self

class Spacecraft(BaseModel):
    """
    Spacecraft
    """ # noqa: E501
    platform_mass: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="platformMass")
    on_board_average_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="onBoardAveragePower")
    duty_cycle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dutyCycle")
    thrust_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrustDuration")
    drag_coefficient: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dragCoefficient")
    lift_ratio: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="liftRatio")
    absorption_coefficient: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="absorptionCoefficient")
    reflection_coefficient: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="reflectionCoefficient")
    platform_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="platformPower")
    max_angular_velocity: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxAngularVelocity")
    max_angular_acceleration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxAngularAcceleration")
    thruster: Optional[PropulsionSystem] = None
    spacecraft_geometry: Optional[SpacecraftGeometry] = Field(default=None, alias="spacecraftGeometry")
    __properties: ClassVar[List[str]] = ["platformMass", "onBoardAveragePower", "dutyCycle", "thrustDuration", "dragCoefficient", "liftRatio", "absorptionCoefficient", "reflectionCoefficient", "platformPower", "maxAngularVelocity", "maxAngularAcceleration", "thruster", "spacecraftGeometry"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Spacecraft from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of thruster
        if self.thruster:
            _dict['thruster'] = self.thruster.to_dict()
        # override the default output from pydantic by calling `to_dict()` of spacecraft_geometry
        if self.spacecraft_geometry:
            _dict['spacecraftGeometry'] = self.spacecraft_geometry.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Spacecraft from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "platformMass": obj.get("platformMass"),
            "onBoardAveragePower": obj.get("onBoardAveragePower"),
            "dutyCycle": obj.get("dutyCycle"),
            "thrustDuration": obj.get("thrustDuration"),
            "dragCoefficient": obj.get("dragCoefficient"),
            "liftRatio": obj.get("liftRatio"),
            "absorptionCoefficient": obj.get("absorptionCoefficient"),
            "reflectionCoefficient": obj.get("reflectionCoefficient"),
            "platformPower": obj.get("platformPower"),
            "maxAngularVelocity": obj.get("maxAngularVelocity"),
            "maxAngularAcceleration": obj.get("maxAngularAcceleration"),
            "thruster": PropulsionSystem.from_dict(obj["thruster"]) if obj.get("thruster") is not None else None,
            "spacecraftGeometry": SpacecraftGeometry.from_dict(obj["spacecraftGeometry"]) if obj.get("spacecraftGeometry") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.orbit_orekit_parameters import OrbitOrekitParameters

class TestOrbitOrekitParameters(unittest.TestCase):
    """OrbitOrekitParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OrbitOrekitParameters:
        """Test OrbitOrekitParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OrbitOrekitParameters`
        """
        model = OrbitOrekitParameters()
        if include_optional:
            return OrbitOrekitParameters(
                type = 'CARTESIAN',
                frame = orbital_transfer.models.frame.Frame(
                    name = '', 
                    parent = orbital_transfer.models.frame.Frame(
                        name = '', 
                        depth = 56, 
                        pseudo_inertial = True, ), 
                    depth = 56, 
                    pseudo_inertial = True, ),
                var_date = '',
                mu = 1.337,
                pv_coordinates = orbital_transfer.models.time_stamped_pv_coordinates.TimeStampedPVCoordinates(
                    date = '', 
                    position = orbital_transfer.models.vector3_d.Vector3D(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, ), 
                    velocity = orbital_transfer.models.vector3_d.Vector3D(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, ), 
                    acceleration = , )
            )
        else:
            return OrbitOrekitParameters(
        )
        """

    def testOrbitOrekitParameters(self):
        """Test OrbitOrekitParameters"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.parametric_propulsion_system import ParametricPropulsionSystem

class TestParametricPropulsionSystem(unittest.TestCase):
    """ParametricPropulsionSystem unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParametricPropulsionSystem:
        """Test ParametricPropulsionSystem
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParametricPropulsionSystem`
        """
        model = ParametricPropulsionSystem()
        if include_optional:
            return ParametricPropulsionSystem(
                total_impulse = 1.337,
                position_in_spacecraft_frame_x = 1.337,
                position_in_spacecraft_frame_y = 1.337,
                position_in_spacecraft_frame_z = 1.337,
                direction_in_spacecraft_frame_x = 1.337,
                direction_in_spacecraft_frame_y = 1.337,
                direction_in_spacecraft_frame_z = 1.337,
                thrust = 1.337,
                isp = 1.337,
                power = 1.337,
                propellant_mass = 1.337,
                total_mass = 1.337,
                standby_power = 1.337,
                warm_up_power = 1.337,
                warm_up_duration = 1.337,
                propellant_capacity_choice = 'PROPELLANT'
            )
        else:
            return ParametricPropulsionSystem(
        )
        """

    def testParametricPropulsionSystem(self):
        """Test ParametricPropulsionSystem"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from orbital_transfer.models.advanced_orbit_parameters import AdvancedOrbitParameters
from orbital_transfer.models.analytical_orbital_transfer_request import AnalyticalOrbitalTransferRequest
from orbital_transfer.models.analytical_orbital_transfer_result import AnalyticalOrbitalTransferResult
from orbital_transfer.models.angular_coordinates import AngularCoordinates
from orbital_transfer.models.bounded_ephemeris import BoundedEphemeris
from orbital_transfer.models.circular_altitude_orbit_parameters import CircularAltitudeOrbitParameters
from orbital_transfer.models.circular_ground_track_repeated_orbit_parameters import CircularGroundTrackRepeatedOrbitParameters
from orbital_transfer.models.double_array_dictionary import DoubleArrayDictionary
from orbital_transfer.models.double_array_dictionary_data_inner import DoubleArrayDictionaryDataInner
from orbital_transfer.models.elliptical_ground_track_repeated_eccentricity_orbit_parameters import EllipticalGroundTrackRepeatedEccentricityOrbitParameters
from orbital_transfer.models.elliptical_perigee_alt_apogee_alt_orbit_parameters import EllipticalPerigeeAltApogeeAltOrbitParameters
from orbital_transfer.models.elliptical_perigee_alt_eccentricity_orbit_parameters import EllipticalPerigeeAltEccentricityOrbitParameters
from orbital_transfer.models.elliptical_sma_eccentricity_orbit_parameters import EllipticalSmaEccentricityOrbitParameters
from orbital_transfer.models.frame import Frame
from orbital_transfer.models.numerical_orbital_transfer_request import NumericalOrbitalTransferRequest
from orbital_transfer.models.numerical_orbital_transfer_result import NumericalOrbitalTransferResult
from orbital_transfer.models.numerical_orbital_transfer_result_field_indexes_inner import NumericalOrbitalTransferResultFieldIndexesInner
from orbital_transfer.models.orbit import Orbit
from orbital_transfer.models.orbit_orekit_parameters import OrbitOrekitParameters
from orbital_transfer.models.orbit_parameters import OrbitParameters
from orbital_transfer.models.parametric_propulsion_system import ParametricPropulsionSystem
from orbital_transfer.models.parametric_spacecraft import ParametricSpacecraft
from orbital_transfer.models.propulsion_system import PropulsionSystem
from orbital_transfer.models.rotation import Rotation
from orbital_transfer.models.spacecraft import Spacecraft
from orbital_transfer.models.spacecraft_geometry import SpacecraftGeometry
from orbital_transfer.models.spacecraft_state import SpacecraftState
from orbital_transfer.models.time_stamped_pv_coordinates import TimeStampedPVCoordinates
from orbital_transfer.models.vector3_d import Vector3D



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.orbit import Orbit

class TestOrbit(unittest.TestCase):
    """Orbit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Orbit:
        """Test Orbit
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Orbit`
        """
        model = Orbit()
        if include_optional:
            return Orbit(
                inclination = 1.337,
                sma = 1.337,
                eccentricity = 1.337,
                parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(),
                advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                    orbit_date = '', 
                    ascending_node_type = 'RAAN', 
                    raan = 1.337, 
                    mltan = 1.337, 
                    anomaly = 1.337, 
                    anomaly_type = 'TRUE', 
                    orbital_element_type = 'MEAN', 
                    perigee_argument = 1.337, )
            )
        else:
            return Orbit(
        )
        """

    def testOrbit(self):
        """Test Orbit"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.rotation import Rotation

class TestRotation(unittest.TestCase):
    """Rotation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Rotation:
        """Test Rotation
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Rotation`
        """
        model = Rotation()
        if include_optional:
            return Rotation(
                q0 = 1.337,
                q1 = 1.337,
                q2 = 1.337,
                q3 = 1.337
            )
        else:
            return Rotation(
        )
        """

    def testRotation(self):
        """Test Rotation"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class AdvancedOrbitParameters(BaseModel):
    """
    AdvancedOrbitParameters
    """ # noqa: E501
    orbit_date: Optional[StrictStr] = Field(default=None, description=" The orbit date", alias="orbitDate")
    ascending_node_type: Optional[StrictStr] = Field(default=None, description=" The orbit ascending node type", alias="ascendingNodeType")
    raan: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description=" The orbit right ascension of the ascending node (in radians)")
    mltan: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description=" The orbit mean local time of the ascending node (in radians)")
    anomaly: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The orbit anomaly (in radians)")
    anomaly_type: Optional[StrictStr] = Field(default=None, description="The orbit anomaly type", alias="anomalyType")
    orbital_element_type: Optional[StrictStr] = Field(default=None, description=" The orbit orbital element type", alias="orbitalElementType")
    perigee_argument: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="The orbit perigee argument (in radians)", alias="perigeeArgument")
    __properties: ClassVar[List[str]] = ["orbitDate", "ascendingNodeType", "raan", "mltan", "anomaly", "anomalyType", "orbitalElementType", "perigeeArgument"]

    @field_validator('ascending_node_type')
    def ascending_node_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['RAAN', 'LTAN', 'NOT_DEFINED']):
            raise ValueError("must be one of enum values ('RAAN', 'LTAN', 'NOT_DEFINED')")
        return value

    @field_validator('anomaly_type')
    def anomaly_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['TRUE', 'MEAN', 'ECCENTRIC']):
            raise ValueError("must be one of enum values ('TRUE', 'MEAN', 'ECCENTRIC')")
        return value

    @field_validator('orbital_element_type')
    def orbital_element_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['MEAN', 'OSC']):
            raise ValueError("must be one of enum values ('MEAN', 'OSC')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AdvancedOrbitParameters from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AdvancedOrbitParameters from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "orbitDate": obj.get("orbitDate"),
            "ascendingNodeType": obj.get("ascendingNodeType"),
            "raan": obj.get("raan"),
            "mltan": obj.get("mltan"),
            "anomaly": obj.get("anomaly"),
            "anomalyType": obj.get("anomalyType"),
            "orbitalElementType": obj.get("orbitalElementType"),
            "perigeeArgument": obj.get("perigeeArgument")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.numerical_orbital_transfer_request import NumericalOrbitalTransferRequest

class TestNumericalOrbitalTransferRequest(unittest.TestCase):
    """NumericalOrbitalTransferRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NumericalOrbitalTransferRequest:
        """Test NumericalOrbitalTransferRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NumericalOrbitalTransferRequest`
        """
        model = NumericalOrbitalTransferRequest()
        if include_optional:
            return NumericalOrbitalTransferRequest(
                mission_date_time = '',
                maximum_duration = 56,
                propagation_type = 'NUMERICAL',
                spacecraft = orbital_transfer.models.spacecraft.Spacecraft(
                    platform_mass = 1.337, 
                    on_board_average_power = 1.337, 
                    duty_cycle = 1.337, 
                    thrust_duration = 1.337, 
                    drag_coefficient = 1.337, 
                    lift_ratio = 1.337, 
                    absorption_coefficient = 1.337, 
                    reflection_coefficient = 1.337, 
                    platform_power = 1.337, 
                    max_angular_velocity = 1.337, 
                    max_angular_acceleration = 1.337, 
                    thruster = orbital_transfer.models.propulsion_system.propulsionSystem(
                        isp = 1.337, 
                        power = 1.337, 
                        thrust = 1.337, 
                        standby_power = 1.337, 
                        warm_up_power = 1.337, 
                        warm_up_duration = 1.337, 
                        propellant_mass = 1.337, 
                        total_mass = 1.337, 
                        total_impulse = 1.337, 
                        maximum_thrust_duration = 1.337, 
                        propellant_capacity_choice = 'PROPELLANT', 
                        propulsion_system_type = 'CHEMICAL', ), 
                    spacecraft_geometry = orbital_transfer.models.spacecraft_geometry.SpacecraftGeometry(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, 
                        inertial_center_in_spacecraft_frame_x = 1.337, 
                        inertial_center_in_spacecraft_frame_y = 1.337, 
                        inertial_center_in_spacecraft_frame_z = 1.337, 
                        inertia_xx = 1.337, 
                        inertia_xy = 1.337, 
                        inertia_xz = 1.337, 
                        inertia_yy = 1.337, 
                        inertia_yz = 1.337, 
                        inertia_zz = 1.337, 
                        inertia_zy = 1.337, 
                        inertia_zx = 1.337, 
                        inertia_yx = 1.337, 
                        thruster_axis_in_satellite_frame_x = 1.337, 
                        thruster_axis_in_satellite_frame_y = 1.337, 
                        thruster_axis_in_satellite_frame_z = 1.337, 
                        body_solar_array_faces = [
                            'PLUS_X'
                            ], 
                        solar_array_efficiency = 1.337, 
                        solar_array_maximum_power = 1.337, 
                        solar_array_surface = 1.337, 
                        solar_array_axis_in_satellite_frame_x = 1.337, 
                        solar_array_axis_in_satellite_frame_y = 1.337, 
                        solar_array_axis_in_satellite_frame_z = 1.337, 
                        solar_array_normal_in_satellite_frame_x = 1.337, 
                        solar_array_normal_in_satellite_frame_y = 1.337, 
                        solar_array_normal_in_satellite_frame_z = 1.337, 
                        payload_pointing_axis_in_satellite_frame_x = 1.337, 
                        payload_pointing_axis_in_satellite_frame_y = 1.337, 
                        payload_pointing_axis_in_satellite_frame_z = 1.337, 
                        antenna_pointing_axis_in_satellite_frame_x = 1.337, 
                        antenna_pointing_axis_in_satellite_frame_y = 1.337, 
                        antenna_pointing_axis_in_satellite_frame_z = 1.337, 
                        spherical_cross_section = 1.337, 
                        solar_array_definition_type = 'MAXIMUM_POWER', 
                        solar_array_type = 'BODY', 
                        type = 'SPHERE', ), ),
                initial_orbit = orbital_transfer.models.orbit.Orbit(
                    inclination = 1.337, 
                    sma = 1.337, 
                    eccentricity = 1.337, 
                    parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(), 
                    advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                        orbit_date = '', 
                        ascending_node_type = 'RAAN', 
                        raan = 1.337, 
                        mltan = 1.337, 
                        anomaly = 1.337, 
                        anomaly_type = 'TRUE', 
                        orbital_element_type = 'MEAN', 
                        perigee_argument = 1.337, ), ),
                target_orbit = orbital_transfer.models.orbit.Orbit(
                    inclination = 1.337, 
                    sma = 1.337, 
                    eccentricity = 1.337, 
                    parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(), 
                    advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                        orbit_date = '', 
                        ascending_node_type = 'RAAN', 
                        raan = 1.337, 
                        mltan = 1.337, 
                        anomaly = 1.337, 
                        anomaly_type = 'TRUE', 
                        orbital_element_type = 'MEAN', 
                        perigee_argument = 1.337, ), ),
                perturbations = [
                    'DRAG'
                    ],
                ephemerides_requested = [
                    'CARTESIAN'
                    ],
                ephemerides_step_in_seconds = 1.337,
                ephemerides_mean_choice = True,
                ephemerides_osc_choice = True,
                custom_solar_flux = 1.337,
                custom_earth_potential_order = 56,
                custom_earth_potential_degree = 56,
                with_eclipse = True
            )
        else:
            return NumericalOrbitalTransferRequest(
                propagation_type = 'NUMERICAL',
                spacecraft = orbital_transfer.models.spacecraft.Spacecraft(
                    platform_mass = 1.337, 
                    on_board_average_power = 1.337, 
                    duty_cycle = 1.337, 
                    thrust_duration = 1.337, 
                    drag_coefficient = 1.337, 
                    lift_ratio = 1.337, 
                    absorption_coefficient = 1.337, 
                    reflection_coefficient = 1.337, 
                    platform_power = 1.337, 
                    max_angular_velocity = 1.337, 
                    max_angular_acceleration = 1.337, 
                    thruster = orbital_transfer.models.propulsion_system.propulsionSystem(
                        isp = 1.337, 
                        power = 1.337, 
                        thrust = 1.337, 
                        standby_power = 1.337, 
                        warm_up_power = 1.337, 
                        warm_up_duration = 1.337, 
                        propellant_mass = 1.337, 
                        total_mass = 1.337, 
                        total_impulse = 1.337, 
                        maximum_thrust_duration = 1.337, 
                        propellant_capacity_choice = 'PROPELLANT', 
                        propulsion_system_type = 'CHEMICAL', ), 
                    spacecraft_geometry = orbital_transfer.models.spacecraft_geometry.SpacecraftGeometry(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, 
                        inertial_center_in_spacecraft_frame_x = 1.337, 
                        inertial_center_in_spacecraft_frame_y = 1.337, 
                        inertial_center_in_spacecraft_frame_z = 1.337, 
                        inertia_xx = 1.337, 
                        inertia_xy = 1.337, 
                        inertia_xz = 1.337, 
                        inertia_yy = 1.337, 
                        inertia_yz = 1.337, 
                        inertia_zz = 1.337, 
                        inertia_zy = 1.337, 
                        inertia_zx = 1.337, 
                        inertia_yx = 1.337, 
                        thruster_axis_in_satellite_frame_x = 1.337, 
                        thruster_axis_in_satellite_frame_y = 1.337, 
                        thruster_axis_in_satellite_frame_z = 1.337, 
                        body_solar_array_faces = [
                            'PLUS_X'
                            ], 
                        solar_array_efficiency = 1.337, 
                        solar_array_maximum_power = 1.337, 
                        solar_array_surface = 1.337, 
                        solar_array_axis_in_satellite_frame_x = 1.337, 
                        solar_array_axis_in_satellite_frame_y = 1.337, 
                        solar_array_axis_in_satellite_frame_z = 1.337, 
                        solar_array_normal_in_satellite_frame_x = 1.337, 
                        solar_array_normal_in_satellite_frame_y = 1.337, 
                        solar_array_normal_in_satellite_frame_z = 1.337, 
                        payload_pointing_axis_in_satellite_frame_x = 1.337, 
                        payload_pointing_axis_in_satellite_frame_y = 1.337, 
                        payload_pointing_axis_in_satellite_frame_z = 1.337, 
                        antenna_pointing_axis_in_satellite_frame_x = 1.337, 
                        antenna_pointing_axis_in_satellite_frame_y = 1.337, 
                        antenna_pointing_axis_in_satellite_frame_z = 1.337, 
                        spherical_cross_section = 1.337, 
                        solar_array_definition_type = 'MAXIMUM_POWER', 
                        solar_array_type = 'BODY', 
                        type = 'SPHERE', ), ),
                initial_orbit = orbital_transfer.models.orbit.Orbit(
                    inclination = 1.337, 
                    sma = 1.337, 
                    eccentricity = 1.337, 
                    parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(), 
                    advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                        orbit_date = '', 
                        ascending_node_type = 'RAAN', 
                        raan = 1.337, 
                        mltan = 1.337, 
                        anomaly = 1.337, 
                        anomaly_type = 'TRUE', 
                        orbital_element_type = 'MEAN', 
                        perigee_argument = 1.337, ), ),
                target_orbit = orbital_transfer.models.orbit.Orbit(
                    inclination = 1.337, 
                    sma = 1.337, 
                    eccentricity = 1.337, 
                    parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(), 
                    advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                        orbit_date = '', 
                        ascending_node_type = 'RAAN', 
                        raan = 1.337, 
                        mltan = 1.337, 
                        anomaly = 1.337, 
                        anomaly_type = 'TRUE', 
                        orbital_element_type = 'MEAN', 
                        perigee_argument = 1.337, ), ),
        )
        """

    def testNumericalOrbitalTransferRequest(self):
        """Test NumericalOrbitalTransferRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.bounded_ephemeris import BoundedEphemeris

class TestBoundedEphemeris(unittest.TestCase):
    """BoundedEphemeris unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BoundedEphemeris:
        """Test BoundedEphemeris
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `BoundedEphemeris`
        """
        model = BoundedEphemeris()
        if include_optional:
            return BoundedEphemeris(
                phase = 'COASTING',
                ephemeris = [
                    orbital_transfer.models.spacecraft_state.SpacecraftState(
                        orbit_orekit_parameters = orbital_transfer.models.orbit_orekit_parameters.OrbitOrekitParameters(
                            type = 'CARTESIAN', 
                            frame = orbital_transfer.models.frame.Frame(
                                name = '', 
                                parent = orbital_transfer.models.frame.Frame(
                                    name = '', 
                                    depth = 56, 
                                    pseudo_inertial = True, ), 
                                depth = 56, 
                                pseudo_inertial = True, ), 
                            date = '', 
                            mu = 1.337, 
                            pv_coordinates = orbital_transfer.models.time_stamped_pv_coordinates.TimeStampedPVCoordinates(
                                date = '', 
                                position = orbital_transfer.models.vector3_d.Vector3D(
                                    x = 1.337, 
                                    y = 1.337, 
                                    z = 1.337, ), 
                                velocity = orbital_transfer.models.vector3_d.Vector3D(
                                    x = 1.337, 
                                    y = 1.337, 
                                    z = 1.337, ), 
                                acceleration = , ), ), 
                        orientation = orbital_transfer.models.angular_coordinates.AngularCoordinates(
                            date = '', 
                            rotation = orbital_transfer.models.rotation.Rotation(
                                q0 = 1.337, 
                                q1 = 1.337, 
                                q2 = 1.337, 
                                q3 = 1.337, ), 
                            rotation_rate = , 
                            rotation_acceleration = , ), 
                        additional = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(
                            data = [
                                orbital_transfer.models.double_array_dictionary_data_inner.DoubleArrayDictionary_data_inner(
                                    key = '', 
                                    value = [
                                        1.337
                                        ], )
                                ], ), 
                        additional_dot = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(), 
                        mass = 1.337, )
                    ],
                orbital_elements_type = 'MEAN'
            )
        else:
            return BoundedEphemeris(
        )
        """

    def testBoundedEphemeris(self):
        """Test BoundedEphemeris"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.spacecraft_geometry import SpacecraftGeometry

class TestSpacecraftGeometry(unittest.TestCase):
    """SpacecraftGeometry unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpacecraftGeometry:
        """Test SpacecraftGeometry
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpacecraftGeometry`
        """
        model = SpacecraftGeometry()
        if include_optional:
            return SpacecraftGeometry(
                x = 1.337,
                y = 1.337,
                z = 1.337,
                inertial_center_in_spacecraft_frame_x = 1.337,
                inertial_center_in_spacecraft_frame_y = 1.337,
                inertial_center_in_spacecraft_frame_z = 1.337,
                inertia_xx = 1.337,
                inertia_xy = 1.337,
                inertia_xz = 1.337,
                inertia_yy = 1.337,
                inertia_yz = 1.337,
                inertia_zz = 1.337,
                inertia_zy = 1.337,
                inertia_zx = 1.337,
                inertia_yx = 1.337,
                thruster_axis_in_satellite_frame_x = 1.337,
                thruster_axis_in_satellite_frame_y = 1.337,
                thruster_axis_in_satellite_frame_z = 1.337,
                body_solar_array_faces = [
                    'PLUS_X'
                    ],
                solar_array_efficiency = 1.337,
                solar_array_maximum_power = 1.337,
                solar_array_surface = 1.337,
                solar_array_axis_in_satellite_frame_x = 1.337,
                solar_array_axis_in_satellite_frame_y = 1.337,
                solar_array_axis_in_satellite_frame_z = 1.337,
                solar_array_normal_in_satellite_frame_x = 1.337,
                solar_array_normal_in_satellite_frame_y = 1.337,
                solar_array_normal_in_satellite_frame_z = 1.337,
                payload_pointing_axis_in_satellite_frame_x = 1.337,
                payload_pointing_axis_in_satellite_frame_y = 1.337,
                payload_pointing_axis_in_satellite_frame_z = 1.337,
                antenna_pointing_axis_in_satellite_frame_x = 1.337,
                antenna_pointing_axis_in_satellite_frame_y = 1.337,
                antenna_pointing_axis_in_satellite_frame_z = 1.337,
                spherical_cross_section = 1.337,
                solar_array_definition_type = 'MAXIMUM_POWER',
                solar_array_type = 'BODY',
                type = 'SPHERE'
            )
        else:
            return SpacecraftGeometry(
        )
        """

    def testSpacecraftGeometry(self):
        """Test SpacecraftGeometry"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.elliptical_sma_eccentricity_orbit_parameters import EllipticalSmaEccentricityOrbitParameters

class TestEllipticalSmaEccentricityOrbitParameters(unittest.TestCase):
    """EllipticalSmaEccentricityOrbitParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EllipticalSmaEccentricityOrbitParameters:
        """Test EllipticalSmaEccentricityOrbitParameters
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EllipticalSmaEccentricityOrbitParameters`
        """
        model = EllipticalSmaEccentricityOrbitParameters()
        if include_optional:
            return EllipticalSmaEccentricityOrbitParameters(
            )
        else:
            return EllipticalSmaEccentricityOrbitParameters(
        )
        """

    def testEllipticalSmaEccentricityOrbitParameters(self):
        """Test EllipticalSmaEccentricityOrbitParameters"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.api.default_api import DefaultApi


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self) -> None:
        self.api = DefaultApi()

    def tearDown(self) -> None:
        pass

    def test_compute_analytical_orbital_transfer(self) -> None:
        """Test case for compute_analytical_orbital_transfer

        compute analytical orbital transfer
        """
        pass

    def test_compute_numerical_orbital_transfer(self) -> None:
        """Test case for compute_numerical_orbital_transfer

        compute numerical orbital transfer
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.spacecraft_state import SpacecraftState

class TestSpacecraftState(unittest.TestCase):
    """SpacecraftState unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SpacecraftState:
        """Test SpacecraftState
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SpacecraftState`
        """
        model = SpacecraftState()
        if include_optional:
            return SpacecraftState(
                orbit_orekit_parameters = orbital_transfer.models.orbit_orekit_parameters.OrbitOrekitParameters(
                    type = 'CARTESIAN', 
                    frame = orbital_transfer.models.frame.Frame(
                        name = '', 
                        parent = orbital_transfer.models.frame.Frame(
                            name = '', 
                            depth = 56, 
                            pseudo_inertial = True, ), 
                        depth = 56, 
                        pseudo_inertial = True, ), 
                    date = '', 
                    mu = 1.337, 
                    pv_coordinates = orbital_transfer.models.time_stamped_pv_coordinates.TimeStampedPVCoordinates(
                        date = '', 
                        position = orbital_transfer.models.vector3_d.Vector3D(
                            x = 1.337, 
                            y = 1.337, 
                            z = 1.337, ), 
                        velocity = orbital_transfer.models.vector3_d.Vector3D(
                            x = 1.337, 
                            y = 1.337, 
                            z = 1.337, ), 
                        acceleration = , ), ),
                orientation = orbital_transfer.models.angular_coordinates.AngularCoordinates(
                    date = '', 
                    rotation = orbital_transfer.models.rotation.Rotation(
                        q0 = 1.337, 
                        q1 = 1.337, 
                        q2 = 1.337, 
                        q3 = 1.337, ), 
                    rotation_rate = orbital_transfer.models.vector3_d.Vector3D(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, ), 
                    rotation_acceleration = orbital_transfer.models.vector3_d.Vector3D(
                        x = 1.337, 
                        y = 1.337, 
                        z = 1.337, ), ),
                additional = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(
                    data = [
                        orbital_transfer.models.double_array_dictionary_data_inner.DoubleArrayDictionary_data_inner(
                            key = '', 
                            value = [
                                1.337
                                ], )
                        ], ),
                additional_dot = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(
                    data = [
                        orbital_transfer.models.double_array_dictionary_data_inner.DoubleArrayDictionary_data_inner(
                            key = '', 
                            value = [
                                1.337
                                ], )
                        ], ),
                mass = 1.337
            )
        else:
            return SpacecraftState(
        )
        """

    def testSpacecraftState(self):
        """Test SpacecraftState"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from orbital_transfer.models.bounded_ephemeris import BoundedEphemeris
from orbital_transfer.models.numerical_orbital_transfer_result_field_indexes_inner import NumericalOrbitalTransferResultFieldIndexesInner
from orbital_transfer.models.orbit import Orbit
from orbital_transfer.models.spacecraft_state import SpacecraftState
from typing import Optional, Set
from typing_extensions import Self

class NumericalOrbitalTransferResult(BaseModel):
    """
    NumericalOrbitalTransferResult
    """ # noqa: E501
    delta_inclination: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="deltaInclination")
    delta_eccentricity: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="deltaEccentricity")
    delta_semi_major_axis: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="deltaSemiMajorAxis")
    total_number_of_burns: Optional[StrictInt] = Field(default=None, description="TODO", alias="totalNumberOfBurns")
    total_burn_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="totalBurnDuration")
    total_consumption: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="totalConsumption")
    total_delta_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="totalDeltaV")
    thruster_duty_cycle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="thrusterDutyCycle")
    total_warmup_duty_cycle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="totalWarmupDutyCycle")
    average_thrust_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="averageThrustDuration")
    simulation_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="simulationDuration")
    number_of_periods: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="numberOfPeriods")
    total_impulse: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="totalImpulse")
    final_duty_cycle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="TODO", alias="finalDutyCycle")
    ephemerides: Optional[List[List[Union[StrictFloat, StrictInt]]]] = Field(default=None, description="TODO")
    field_indexes: Optional[List[NumericalOrbitalTransferResultFieldIndexesInner]] = Field(default=None, description="TODO", alias="fieldIndexes")
    threed_ephemerides: Optional[List[List[Union[StrictFloat, StrictInt]]]] = Field(default=None, description="TODO", alias="threedEphemerides")
    threed_field_indexes: Optional[List[NumericalOrbitalTransferResultFieldIndexesInner]] = Field(default=None, description="TODO", alias="threedFieldIndexes")
    osc_bounded_ephemerides: Optional[List[BoundedEphemeris]] = Field(default=None, description="TODO", alias="oscBoundedEphemerides")
    mean_bounded_ephemerides: Optional[List[BoundedEphemeris]] = Field(default=None, description="TODO", alias="meanBoundedEphemerides")
    osc_ephemerides_for_thrust: Optional[List[SpacecraftState]] = Field(default=None, description="TODO", alias="oscEphemeridesForThrust")
    ephemerides_frame: Optional[StrictStr] = Field(default=None, description="TODO", alias="ephemeridesFrame")
    maneuver_model: Optional[StrictStr] = Field(default=None, description="TODO", alias="maneuverModel")
    final_orbit: Optional[Orbit] = Field(default=None, alias="finalOrbit")
    errors: Optional[List[StrictStr]] = None
    warnings: Optional[List[StrictStr]] = None
    computation_date: Optional[StrictStr] = Field(default=None, alias="computationDate")
    __properties: ClassVar[List[str]] = ["deltaInclination", "deltaEccentricity", "deltaSemiMajorAxis", "totalNumberOfBurns", "totalBurnDuration", "totalConsumption", "totalDeltaV", "thrusterDutyCycle", "totalWarmupDutyCycle", "averageThrustDuration", "simulationDuration", "numberOfPeriods", "totalImpulse", "finalDutyCycle", "ephemerides", "fieldIndexes", "threedEphemerides", "threedFieldIndexes", "oscBoundedEphemerides", "meanBoundedEphemerides", "oscEphemeridesForThrust", "ephemeridesFrame", "maneuverModel", "finalOrbit", "errors", "warnings", "computationDate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NumericalOrbitalTransferResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in field_indexes (list)
        _items = []
        if self.field_indexes:
            for _item in self.field_indexes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fieldIndexes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in threed_field_indexes (list)
        _items = []
        if self.threed_field_indexes:
            for _item in self.threed_field_indexes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['threedFieldIndexes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in osc_bounded_ephemerides (list)
        _items = []
        if self.osc_bounded_ephemerides:
            for _item in self.osc_bounded_ephemerides:
                if _item:
                    _items.append(_item.to_dict())
            _dict['oscBoundedEphemerides'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in mean_bounded_ephemerides (list)
        _items = []
        if self.mean_bounded_ephemerides:
            for _item in self.mean_bounded_ephemerides:
                if _item:
                    _items.append(_item.to_dict())
            _dict['meanBoundedEphemerides'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in osc_ephemerides_for_thrust (list)
        _items = []
        if self.osc_ephemerides_for_thrust:
            for _item in self.osc_ephemerides_for_thrust:
                if _item:
                    _items.append(_item.to_dict())
            _dict['oscEphemeridesForThrust'] = _items
        # override the default output from pydantic by calling `to_dict()` of final_orbit
        if self.final_orbit:
            _dict['finalOrbit'] = self.final_orbit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NumericalOrbitalTransferResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "deltaInclination": obj.get("deltaInclination"),
            "deltaEccentricity": obj.get("deltaEccentricity"),
            "deltaSemiMajorAxis": obj.get("deltaSemiMajorAxis"),
            "totalNumberOfBurns": obj.get("totalNumberOfBurns"),
            "totalBurnDuration": obj.get("totalBurnDuration"),
            "totalConsumption": obj.get("totalConsumption"),
            "totalDeltaV": obj.get("totalDeltaV"),
            "thrusterDutyCycle": obj.get("thrusterDutyCycle"),
            "totalWarmupDutyCycle": obj.get("totalWarmupDutyCycle"),
            "averageThrustDuration": obj.get("averageThrustDuration"),
            "simulationDuration": obj.get("simulationDuration"),
            "numberOfPeriods": obj.get("numberOfPeriods"),
            "totalImpulse": obj.get("totalImpulse"),
            "finalDutyCycle": obj.get("finalDutyCycle"),
            "ephemerides": obj.get("ephemerides"),
            "fieldIndexes": [NumericalOrbitalTransferResultFieldIndexesInner.from_dict(_item) for _item in obj["fieldIndexes"]] if obj.get("fieldIndexes") is not None else None,
            "threedEphemerides": obj.get("threedEphemerides"),
            "threedFieldIndexes": [NumericalOrbitalTransferResultFieldIndexesInner.from_dict(_item) for _item in obj["threedFieldIndexes"]] if obj.get("threedFieldIndexes") is not None else None,
            "oscBoundedEphemerides": [BoundedEphemeris.from_dict(_item) for _item in obj["oscBoundedEphemerides"]] if obj.get("oscBoundedEphemerides") is not None else None,
            "meanBoundedEphemerides": [BoundedEphemeris.from_dict(_item) for _item in obj["meanBoundedEphemerides"]] if obj.get("meanBoundedEphemerides") is not None else None,
            "oscEphemeridesForThrust": [SpacecraftState.from_dict(_item) for _item in obj["oscEphemeridesForThrust"]] if obj.get("oscEphemeridesForThrust") is not None else None,
            "ephemeridesFrame": obj.get("ephemeridesFrame"),
            "maneuverModel": obj.get("maneuverModel"),
            "finalOrbit": Orbit.from_dict(obj["finalOrbit"]) if obj.get("finalOrbit") is not None else None,
            "errors": obj.get("errors"),
            "warnings": obj.get("warnings"),
            "computationDate": obj.get("computationDate")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.parametric_spacecraft import ParametricSpacecraft

class TestParametricSpacecraft(unittest.TestCase):
    """ParametricSpacecraft unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ParametricSpacecraft:
        """Test ParametricSpacecraft
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ParametricSpacecraft`
        """
        model = ParametricSpacecraft()
        if include_optional:
            return ParametricSpacecraft(
                platform_mass = 1.337,
                orbital_average_power = 1.337,
                custom_orbital_duty_cycle = True,
                orbital_duty_cycle = 1.337,
                drag_area = 1.337,
                drag_coefficient = 1.337,
                solar_radiation_pressure_center_in_spacecraft_frame_x = 1.337,
                solar_radiation_pressure_center_in_spacecraft_frame_y = 1.337,
                solar_radiation_pressure_center_in_spacecraft_frame_z = 1.337,
                inertia_xx = 1.337,
                inertia_xy = 1.337,
                inertia_xz = 1.337,
                inertia_yy = 1.337,
                inertia_yz = 1.337,
                inertia_zz = 1.337,
                inertia_zx = 1.337,
                inertia_zy = 1.337,
                inertia_yx = 1.337,
                max_angular_rate = 1.337,
                min_angular_rate = 1.337,
                thruster = orbital_transfer.models.parametric_propulsion_system.ParametricPropulsionSystem(
                    total_impulse = 1.337, 
                    position_in_spacecraft_frame_x = 1.337, 
                    position_in_spacecraft_frame_y = 1.337, 
                    position_in_spacecraft_frame_z = 1.337, 
                    direction_in_spacecraft_frame_x = 1.337, 
                    direction_in_spacecraft_frame_y = 1.337, 
                    direction_in_spacecraft_frame_z = 1.337, 
                    thrust = 1.337, 
                    isp = 1.337, 
                    power = 1.337, 
                    propellant_mass = 1.337, 
                    total_mass = 1.337, 
                    standby_power = 1.337, 
                    warm_up_power = 1.337, 
                    warm_up_duration = 1.337, 
                    propellant_capacity_choice = 'PROPELLANT', )
            )
        else:
            return ParametricSpacecraft(
        )
        """

    def testParametricSpacecraft(self):
        """Test ParametricSpacecraft"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class AnalyticalOrbitalTransferResult(BaseModel):
    """
    AnalyticalOrbitalTransferResult
    """ # noqa: E501
    delta_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaV")
    delta_inclination: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaInclination")
    delta_semi_major_axis: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaSemiMajorAxis")
    delta_eccentricity: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="deltaEccentricity")
    maneuvering_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maneuveringDuration")
    mission_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="missionDuration")
    thrust_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrustDuration")
    thruster_mean_duty_cycle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrusterMeanDutyCycle")
    total_impulse: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalImpulse")
    used_propellant: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="usedPropellant")
    number_of_burns: Optional[StrictInt] = Field(default=None, alias="numberOfBurns")
    mean_burn_duration_estimation: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanBurnDurationEstimation")
    drag_perturbation_enabled: Optional[StrictBool] = Field(default=None, alias="dragPerturbationEnabled")
    mean_atmospheric_density: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanAtmosphericDensity")
    mean_drag: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanDrag")
    mean_drag_acceleration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="meanDragAcceleration")
    drag_to_thrust_ratio: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dragToThrustRatio")
    drag_delta_v: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dragDeltaV")
    maneuver_model: Optional[StrictStr] = Field(default=None, alias="maneuverModel")
    errors: Optional[List[StrictStr]] = None
    warnings: Optional[List[StrictStr]] = None
    computation_date: Optional[StrictStr] = Field(default=None, alias="computationDate")
    __properties: ClassVar[List[str]] = ["deltaV", "deltaInclination", "deltaSemiMajorAxis", "deltaEccentricity", "maneuveringDuration", "missionDuration", "thrustDuration", "thrusterMeanDutyCycle", "totalImpulse", "usedPropellant", "numberOfBurns", "meanBurnDurationEstimation", "dragPerturbationEnabled", "meanAtmosphericDensity", "meanDrag", "meanDragAcceleration", "dragToThrustRatio", "dragDeltaV", "maneuverModel", "errors", "warnings", "computationDate"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AnalyticalOrbitalTransferResult from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AnalyticalOrbitalTransferResult from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "deltaV": obj.get("deltaV"),
            "deltaInclination": obj.get("deltaInclination"),
            "deltaSemiMajorAxis": obj.get("deltaSemiMajorAxis"),
            "deltaEccentricity": obj.get("deltaEccentricity"),
            "maneuveringDuration": obj.get("maneuveringDuration"),
            "missionDuration": obj.get("missionDuration"),
            "thrustDuration": obj.get("thrustDuration"),
            "thrusterMeanDutyCycle": obj.get("thrusterMeanDutyCycle"),
            "totalImpulse": obj.get("totalImpulse"),
            "usedPropellant": obj.get("usedPropellant"),
            "numberOfBurns": obj.get("numberOfBurns"),
            "meanBurnDurationEstimation": obj.get("meanBurnDurationEstimation"),
            "dragPerturbationEnabled": obj.get("dragPerturbationEnabled"),
            "meanAtmosphericDensity": obj.get("meanAtmosphericDensity"),
            "meanDrag": obj.get("meanDrag"),
            "meanDragAcceleration": obj.get("meanDragAcceleration"),
            "dragToThrustRatio": obj.get("dragToThrustRatio"),
            "dragDeltaV": obj.get("dragDeltaV"),
            "maneuverModel": obj.get("maneuverModel"),
            "errors": obj.get("errors"),
            "warnings": obj.get("warnings"),
            "computationDate": obj.get("computationDate")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from orbital_transfer.models.orbit import Orbit
from orbital_transfer.models.spacecraft import Spacecraft
from typing import Optional, Set
from typing_extensions import Self

class NumericalOrbitalTransferRequest(BaseModel):
    """
    NumericalOrbitalTransferRequest
    """ # noqa: E501
    mission_date_time: Optional[StrictStr] = Field(default=None, description="The simulation date", alias="missionDateTime")
    maximum_duration: Optional[StrictInt] = Field(default=None, description="The simulation maximum duration (in days)", alias="maximumDuration")
    propagation_type: StrictStr = Field(description="The type of propagation to use for the computation", alias="propagationType")
    spacecraft: Spacecraft
    initial_orbit: Orbit = Field(alias="initialOrbit")
    target_orbit: Orbit = Field(alias="targetOrbit")
    perturbations: Optional[List[StrictStr]] = Field(default=None, description="The perturbations to take into account for the propagation")
    ephemerides_requested: Optional[List[StrictStr]] = Field(default=None, alias="ephemeridesRequested")
    ephemerides_step_in_seconds: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="ephemeridesStepInSeconds")
    ephemerides_mean_choice: Optional[StrictBool] = Field(default=None, alias="ephemeridesMeanChoice")
    ephemerides_osc_choice: Optional[StrictBool] = Field(default=None, alias="ephemeridesOscChoice")
    custom_solar_flux: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="If drag perturbation is enabled, the custom solar flux to use", alias="customSolarFlux")
    custom_earth_potential_order: Optional[StrictInt] = Field(default=None, description="If earth potential perturbation is enabled, the custom earth potential order", alias="customEarthPotentialOrder")
    custom_earth_potential_degree: Optional[StrictInt] = Field(default=None, description="If earth potential perturbation is enabled, the custom earth potential degree", alias="customEarthPotentialDegree")
    with_eclipse: Optional[StrictBool] = Field(default=None, description=" Indicates whether to take eclipse into consideration or not", alias="withEclipse")
    __properties: ClassVar[List[str]] = ["missionDateTime", "maximumDuration", "propagationType", "spacecraft", "initialOrbit", "targetOrbit", "perturbations", "ephemeridesRequested", "ephemeridesStepInSeconds", "ephemeridesMeanChoice", "ephemeridesOscChoice", "customSolarFlux", "customEarthPotentialOrder", "customEarthPotentialDegree", "withEclipse"]

    @field_validator('propagation_type')
    def propagation_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['NUMERICAL', 'SEMI_ANALYTICAL']):
            raise ValueError("must be one of enum values ('NUMERICAL', 'SEMI_ANALYTICAL')")
        return value

    @field_validator('perturbations')
    def perturbations_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['DRAG', 'SRP', 'EARTH_POTENTIAL', 'THIRD_BODY']):
                raise ValueError("each list item must be one of ('DRAG', 'SRP', 'EARTH_POTENTIAL', 'THIRD_BODY')")
        return value

    @field_validator('ephemerides_requested')
    def ephemerides_requested_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['CARTESIAN', 'KEPLERIAN', 'CIRCULAR', 'EQUINOCTIAL', 'THRUST', 'SYSTEM', 'ECLIPSE', 'ATTITUDE', 'MANOEUVRING_STRATEGIES', 'CESIUM_POSITION', 'CESIUM_ATTITUDE', 'THRUSTER_AXES_CONSUMPTION', 'QUATERNIONS', 'EULER_ANGLES', 'LINK_BUDGET']):
                raise ValueError("each list item must be one of ('CARTESIAN', 'KEPLERIAN', 'CIRCULAR', 'EQUINOCTIAL', 'THRUST', 'SYSTEM', 'ECLIPSE', 'ATTITUDE', 'MANOEUVRING_STRATEGIES', 'CESIUM_POSITION', 'CESIUM_ATTITUDE', 'THRUSTER_AXES_CONSUMPTION', 'QUATERNIONS', 'EULER_ANGLES', 'LINK_BUDGET')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NumericalOrbitalTransferRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of spacecraft
        if self.spacecraft:
            _dict['spacecraft'] = self.spacecraft.to_dict()
        # override the default output from pydantic by calling `to_dict()` of initial_orbit
        if self.initial_orbit:
            _dict['initialOrbit'] = self.initial_orbit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of target_orbit
        if self.target_orbit:
            _dict['targetOrbit'] = self.target_orbit.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NumericalOrbitalTransferRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "missionDateTime": obj.get("missionDateTime"),
            "maximumDuration": obj.get("maximumDuration"),
            "propagationType": obj.get("propagationType"),
            "spacecraft": Spacecraft.from_dict(obj["spacecraft"]) if obj.get("spacecraft") is not None else None,
            "initialOrbit": Orbit.from_dict(obj["initialOrbit"]) if obj.get("initialOrbit") is not None else None,
            "targetOrbit": Orbit.from_dict(obj["targetOrbit"]) if obj.get("targetOrbit") is not None else None,
            "perturbations": obj.get("perturbations"),
            "ephemeridesRequested": obj.get("ephemeridesRequested"),
            "ephemeridesStepInSeconds": obj.get("ephemeridesStepInSeconds"),
            "ephemeridesMeanChoice": obj.get("ephemeridesMeanChoice"),
            "ephemeridesOscChoice": obj.get("ephemeridesOscChoice"),
            "customSolarFlux": obj.get("customSolarFlux"),
            "customEarthPotentialOrder": obj.get("customEarthPotentialOrder"),
            "customEarthPotentialDegree": obj.get("customEarthPotentialDegree"),
            "withEclipse": obj.get("withEclipse")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt
from typing import Any, ClassVar, Dict, List, Optional, Union
from orbital_transfer.models.parametric_propulsion_system import ParametricPropulsionSystem
from typing import Optional, Set
from typing_extensions import Self

class ParametricSpacecraft(BaseModel):
    """
    ParametricSpacecraft
    """ # noqa: E501
    platform_mass: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="platformMass")
    orbital_average_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="orbitalAveragePower")
    custom_orbital_duty_cycle: Optional[StrictBool] = Field(default=None, alias="customOrbitalDutyCycle")
    orbital_duty_cycle: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="orbitalDutyCycle")
    drag_area: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dragArea")
    drag_coefficient: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="dragCoefficient")
    solar_radiation_pressure_center_in_spacecraft_frame_x: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarRadiationPressureCenterInSpacecraftFrameX")
    solar_radiation_pressure_center_in_spacecraft_frame_y: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarRadiationPressureCenterInSpacecraftFrameY")
    solar_radiation_pressure_center_in_spacecraft_frame_z: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarRadiationPressureCenterInSpacecraftFrameZ")
    inertia_xx: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaXX")
    inertia_xy: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaXY")
    inertia_xz: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaXZ")
    inertia_yy: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaYY")
    inertia_yz: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaYZ")
    inertia_zz: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaZZ")
    inertia_zx: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaZX")
    inertia_zy: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaZY")
    inertia_yx: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaYX")
    max_angular_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maxAngularRate")
    min_angular_rate: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="minAngularRate")
    thruster: Optional[ParametricPropulsionSystem] = None
    __properties: ClassVar[List[str]] = ["platformMass", "orbitalAveragePower", "customOrbitalDutyCycle", "orbitalDutyCycle", "dragArea", "dragCoefficient", "solarRadiationPressureCenterInSpacecraftFrameX", "solarRadiationPressureCenterInSpacecraftFrameY", "solarRadiationPressureCenterInSpacecraftFrameZ", "inertiaXX", "inertiaXY", "inertiaXZ", "inertiaYY", "inertiaYZ", "inertiaZZ", "inertiaZX", "inertiaZY", "inertiaYX", "maxAngularRate", "minAngularRate", "thruster"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ParametricSpacecraft from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of thruster
        if self.thruster:
            _dict['thruster'] = self.thruster.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ParametricSpacecraft from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "platformMass": obj.get("platformMass"),
            "orbitalAveragePower": obj.get("orbitalAveragePower"),
            "customOrbitalDutyCycle": obj.get("customOrbitalDutyCycle"),
            "orbitalDutyCycle": obj.get("orbitalDutyCycle"),
            "dragArea": obj.get("dragArea"),
            "dragCoefficient": obj.get("dragCoefficient"),
            "solarRadiationPressureCenterInSpacecraftFrameX": obj.get("solarRadiationPressureCenterInSpacecraftFrameX"),
            "solarRadiationPressureCenterInSpacecraftFrameY": obj.get("solarRadiationPressureCenterInSpacecraftFrameY"),
            "solarRadiationPressureCenterInSpacecraftFrameZ": obj.get("solarRadiationPressureCenterInSpacecraftFrameZ"),
            "inertiaXX": obj.get("inertiaXX"),
            "inertiaXY": obj.get("inertiaXY"),
            "inertiaXZ": obj.get("inertiaXZ"),
            "inertiaYY": obj.get("inertiaYY"),
            "inertiaYZ": obj.get("inertiaYZ"),
            "inertiaZZ": obj.get("inertiaZZ"),
            "inertiaZX": obj.get("inertiaZX"),
            "inertiaZY": obj.get("inertiaZY"),
            "inertiaYX": obj.get("inertiaYX"),
            "maxAngularRate": obj.get("maxAngularRate"),
            "minAngularRate": obj.get("minAngularRate"),
            "thruster": ParametricPropulsionSystem.from_dict(obj["thruster"]) if obj.get("thruster") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.numerical_orbital_transfer_result import NumericalOrbitalTransferResult

class TestNumericalOrbitalTransferResult(unittest.TestCase):
    """NumericalOrbitalTransferResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> NumericalOrbitalTransferResult:
        """Test NumericalOrbitalTransferResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `NumericalOrbitalTransferResult`
        """
        model = NumericalOrbitalTransferResult()
        if include_optional:
            return NumericalOrbitalTransferResult(
                delta_inclination = 1.337,
                delta_eccentricity = 1.337,
                delta_semi_major_axis = 1.337,
                total_number_of_burns = 56,
                total_burn_duration = 1.337,
                total_consumption = 1.337,
                total_delta_v = 1.337,
                thruster_duty_cycle = 1.337,
                total_warmup_duty_cycle = 1.337,
                average_thrust_duration = 1.337,
                simulation_duration = 1.337,
                number_of_periods = 1.337,
                total_impulse = 1.337,
                final_duty_cycle = 1.337,
                ephemerides = [
                    [
                        1.337
                        ]
                    ],
                field_indexes = [
                    orbital_transfer.models.numerical_orbital_transfer_result_field_indexes_inner.NumericalOrbitalTransferResult_fieldIndexes_inner(
                        key = '', 
                        index = 56, )
                    ],
                threed_ephemerides = [
                    [
                        1.337
                        ]
                    ],
                threed_field_indexes = [
                    orbital_transfer.models.numerical_orbital_transfer_result_field_indexes_inner.NumericalOrbitalTransferResult_fieldIndexes_inner(
                        key = '', 
                        index = 56, )
                    ],
                osc_bounded_ephemerides = [
                    orbital_transfer.models.bounded_ephemeris.BoundedEphemeris(
                        phase = 'COASTING', 
                        ephemeris = [
                            orbital_transfer.models.spacecraft_state.SpacecraftState(
                                orbit_orekit_parameters = orbital_transfer.models.orbit_orekit_parameters.OrbitOrekitParameters(
                                    type = 'CARTESIAN', 
                                    frame = orbital_transfer.models.frame.Frame(
                                        name = '', 
                                        parent = orbital_transfer.models.frame.Frame(
                                            name = '', 
                                            depth = 56, 
                                            pseudo_inertial = True, ), 
                                        depth = 56, 
                                        pseudo_inertial = True, ), 
                                    date = '', 
                                    mu = 1.337, 
                                    pv_coordinates = orbital_transfer.models.time_stamped_pv_coordinates.TimeStampedPVCoordinates(
                                        date = '', 
                                        position = orbital_transfer.models.vector3_d.Vector3D(
                                            x = 1.337, 
                                            y = 1.337, 
                                            z = 1.337, ), 
                                        velocity = orbital_transfer.models.vector3_d.Vector3D(
                                            x = 1.337, 
                                            y = 1.337, 
                                            z = 1.337, ), 
                                        acceleration = , ), ), 
                                orientation = orbital_transfer.models.angular_coordinates.AngularCoordinates(
                                    date = '', 
                                    rotation = orbital_transfer.models.rotation.Rotation(
                                        q0 = 1.337, 
                                        q1 = 1.337, 
                                        q2 = 1.337, 
                                        q3 = 1.337, ), 
                                    rotation_rate = , 
                                    rotation_acceleration = , ), 
                                additional = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(
                                    data = [
                                        orbital_transfer.models.double_array_dictionary_data_inner.DoubleArrayDictionary_data_inner(
                                            key = '', 
                                            value = [
                                                1.337
                                                ], )
                                        ], ), 
                                additional_dot = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(), 
                                mass = 1.337, )
                            ], 
                        orbital_elements_type = 'MEAN', )
                    ],
                mean_bounded_ephemerides = [
                    orbital_transfer.models.bounded_ephemeris.BoundedEphemeris(
                        phase = 'COASTING', 
                        ephemeris = [
                            orbital_transfer.models.spacecraft_state.SpacecraftState(
                                orbit_orekit_parameters = orbital_transfer.models.orbit_orekit_parameters.OrbitOrekitParameters(
                                    type = 'CARTESIAN', 
                                    frame = orbital_transfer.models.frame.Frame(
                                        name = '', 
                                        parent = orbital_transfer.models.frame.Frame(
                                            name = '', 
                                            depth = 56, 
                                            pseudo_inertial = True, ), 
                                        depth = 56, 
                                        pseudo_inertial = True, ), 
                                    date = '', 
                                    mu = 1.337, 
                                    pv_coordinates = orbital_transfer.models.time_stamped_pv_coordinates.TimeStampedPVCoordinates(
                                        date = '', 
                                        position = orbital_transfer.models.vector3_d.Vector3D(
                                            x = 1.337, 
                                            y = 1.337, 
                                            z = 1.337, ), 
                                        velocity = orbital_transfer.models.vector3_d.Vector3D(
                                            x = 1.337, 
                                            y = 1.337, 
                                            z = 1.337, ), 
                                        acceleration = , ), ), 
                                orientation = orbital_transfer.models.angular_coordinates.AngularCoordinates(
                                    date = '', 
                                    rotation = orbital_transfer.models.rotation.Rotation(
                                        q0 = 1.337, 
                                        q1 = 1.337, 
                                        q2 = 1.337, 
                                        q3 = 1.337, ), 
                                    rotation_rate = , 
                                    rotation_acceleration = , ), 
                                additional = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(
                                    data = [
                                        orbital_transfer.models.double_array_dictionary_data_inner.DoubleArrayDictionary_data_inner(
                                            key = '', 
                                            value = [
                                                1.337
                                                ], )
                                        ], ), 
                                additional_dot = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(), 
                                mass = 1.337, )
                            ], 
                        orbital_elements_type = 'MEAN', )
                    ],
                osc_ephemerides_for_thrust = [
                    orbital_transfer.models.spacecraft_state.SpacecraftState(
                        orbit_orekit_parameters = orbital_transfer.models.orbit_orekit_parameters.OrbitOrekitParameters(
                            type = 'CARTESIAN', 
                            frame = orbital_transfer.models.frame.Frame(
                                name = '', 
                                parent = orbital_transfer.models.frame.Frame(
                                    name = '', 
                                    depth = 56, 
                                    pseudo_inertial = True, ), 
                                depth = 56, 
                                pseudo_inertial = True, ), 
                            date = '', 
                            mu = 1.337, 
                            pv_coordinates = orbital_transfer.models.time_stamped_pv_coordinates.TimeStampedPVCoordinates(
                                date = '', 
                                position = orbital_transfer.models.vector3_d.Vector3D(
                                    x = 1.337, 
                                    y = 1.337, 
                                    z = 1.337, ), 
                                velocity = orbital_transfer.models.vector3_d.Vector3D(
                                    x = 1.337, 
                                    y = 1.337, 
                                    z = 1.337, ), 
                                acceleration = , ), ), 
                        orientation = orbital_transfer.models.angular_coordinates.AngularCoordinates(
                            date = '', 
                            rotation = orbital_transfer.models.rotation.Rotation(
                                q0 = 1.337, 
                                q1 = 1.337, 
                                q2 = 1.337, 
                                q3 = 1.337, ), 
                            rotation_rate = , 
                            rotation_acceleration = , ), 
                        additional = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(
                            data = [
                                orbital_transfer.models.double_array_dictionary_data_inner.DoubleArrayDictionary_data_inner(
                                    key = '', 
                                    value = [
                                        1.337
                                        ], )
                                ], ), 
                        additional_dot = orbital_transfer.models.double_array_dictionary.DoubleArrayDictionary(), 
                        mass = 1.337, )
                    ],
                ephemerides_frame = '',
                maneuver_model = '',
                final_orbit = orbital_transfer.models.orbit.Orbit(
                    inclination = 1.337, 
                    sma = 1.337, 
                    eccentricity = 1.337, 
                    parameters = orbital_transfer.models.orbit_parameters.OrbitParameters(), 
                    advanced_parameters = orbital_transfer.models.advanced_orbit_parameters.AdvancedOrbitParameters(
                        orbit_date = '', 
                        ascending_node_type = 'RAAN', 
                        raan = 1.337, 
                        mltan = 1.337, 
                        anomaly = 1.337, 
                        anomaly_type = 'TRUE', 
                        orbital_element_type = 'MEAN', 
                        perigee_argument = 1.337, ), ),
                errors = [
                    ''
                    ],
                warnings = [
                    ''
                    ],
                computation_date = ''
            )
        else:
            return NumericalOrbitalTransferResult(
        )
        """

    def testNumericalOrbitalTransferResult(self):
        """Test NumericalOrbitalTransferResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.spacecraft import Spacecraft

class TestSpacecraft(unittest.TestCase):
    """Spacecraft unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Spacecraft:
        """Test Spacecraft
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Spacecraft`
        """
        model = Spacecraft()
        if include_optional:
            return Spacecraft(
                platform_mass = 1.337,
                on_board_average_power = 1.337,
                duty_cycle = 1.337,
                thrust_duration = 1.337,
                drag_coefficient = 1.337,
                lift_ratio = 1.337,
                absorption_coefficient = 1.337,
                reflection_coefficient = 1.337,
                platform_power = 1.337,
                max_angular_velocity = 1.337,
                max_angular_acceleration = 1.337,
                thruster = orbital_transfer.models.propulsion_system.propulsionSystem(
                    isp = 1.337, 
                    power = 1.337, 
                    thrust = 1.337, 
                    standby_power = 1.337, 
                    warm_up_power = 1.337, 
                    warm_up_duration = 1.337, 
                    propellant_mass = 1.337, 
                    total_mass = 1.337, 
                    total_impulse = 1.337, 
                    maximum_thrust_duration = 1.337, 
                    propellant_capacity_choice = 'PROPELLANT', 
                    propulsion_system_type = 'CHEMICAL', ),
                spacecraft_geometry = orbital_transfer.models.spacecraft_geometry.SpacecraftGeometry(
                    x = 1.337, 
                    y = 1.337, 
                    z = 1.337, 
                    inertial_center_in_spacecraft_frame_x = 1.337, 
                    inertial_center_in_spacecraft_frame_y = 1.337, 
                    inertial_center_in_spacecraft_frame_z = 1.337, 
                    inertia_xx = 1.337, 
                    inertia_xy = 1.337, 
                    inertia_xz = 1.337, 
                    inertia_yy = 1.337, 
                    inertia_yz = 1.337, 
                    inertia_zz = 1.337, 
                    inertia_zy = 1.337, 
                    inertia_zx = 1.337, 
                    inertia_yx = 1.337, 
                    thruster_axis_in_satellite_frame_x = 1.337, 
                    thruster_axis_in_satellite_frame_y = 1.337, 
                    thruster_axis_in_satellite_frame_z = 1.337, 
                    body_solar_array_faces = [
                        'PLUS_X'
                        ], 
                    solar_array_efficiency = 1.337, 
                    solar_array_maximum_power = 1.337, 
                    solar_array_surface = 1.337, 
                    solar_array_axis_in_satellite_frame_x = 1.337, 
                    solar_array_axis_in_satellite_frame_y = 1.337, 
                    solar_array_axis_in_satellite_frame_z = 1.337, 
                    solar_array_normal_in_satellite_frame_x = 1.337, 
                    solar_array_normal_in_satellite_frame_y = 1.337, 
                    solar_array_normal_in_satellite_frame_z = 1.337, 
                    payload_pointing_axis_in_satellite_frame_x = 1.337, 
                    payload_pointing_axis_in_satellite_frame_y = 1.337, 
                    payload_pointing_axis_in_satellite_frame_z = 1.337, 
                    antenna_pointing_axis_in_satellite_frame_x = 1.337, 
                    antenna_pointing_axis_in_satellite_frame_y = 1.337, 
                    antenna_pointing_axis_in_satellite_frame_z = 1.337, 
                    spherical_cross_section = 1.337, 
                    solar_array_definition_type = 'MAXIMUM_POWER', 
                    solar_array_type = 'BODY', 
                    type = 'SPHERE', )
            )
        else:
            return Spacecraft(
        )
        """

    def testSpacecraft(self):
        """Test Spacecraft"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class PropulsionSystem(BaseModel):
    """
    PropulsionSystem
    """ # noqa: E501
    isp: Optional[Union[StrictFloat, StrictInt]] = None
    power: Optional[Union[StrictFloat, StrictInt]] = None
    thrust: Optional[Union[StrictFloat, StrictInt]] = None
    standby_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="standbyPower")
    warm_up_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="warmUpPower")
    warm_up_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="warmUpDuration")
    propellant_mass: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="propellantMass")
    total_mass: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalMass")
    total_impulse: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="totalImpulse")
    maximum_thrust_duration: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="maximumThrustDuration")
    propellant_capacity_choice: Optional[StrictStr] = Field(default=None, alias="propellantCapacityChoice")
    propulsion_system_type: Optional[StrictStr] = Field(default=None, alias="propulsionSystemType")
    __properties: ClassVar[List[str]] = ["isp", "power", "thrust", "standbyPower", "warmUpPower", "warmUpDuration", "propellantMass", "totalMass", "totalImpulse", "maximumThrustDuration", "propellantCapacityChoice", "propulsionSystemType"]

    @field_validator('propellant_capacity_choice')
    def propellant_capacity_choice_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['PROPELLANT', 'TOTAL_IMPULSE']):
            raise ValueError("must be one of enum values ('PROPELLANT', 'TOTAL_IMPULSE')")
        return value

    @field_validator('propulsion_system_type')
    def propulsion_system_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['CHEMICAL', 'ELECTRICAL']):
            raise ValueError("must be one of enum values ('CHEMICAL', 'ELECTRICAL')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PropulsionSystem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PropulsionSystem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "isp": obj.get("isp"),
            "power": obj.get("power"),
            "thrust": obj.get("thrust"),
            "standbyPower": obj.get("standbyPower"),
            "warmUpPower": obj.get("warmUpPower"),
            "warmUpDuration": obj.get("warmUpDuration"),
            "propellantMass": obj.get("propellantMass"),
            "totalMass": obj.get("totalMass"),
            "totalImpulse": obj.get("totalImpulse"),
            "maximumThrustDuration": obj.get("maximumThrustDuration"),
            "propellantCapacityChoice": obj.get("propellantCapacityChoice"),
            "propulsionSystemType": obj.get("propulsionSystemType")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class SpacecraftGeometry(BaseModel):
    """
    SpacecraftGeometry
    """ # noqa: E501
    x: Optional[Union[StrictFloat, StrictInt]] = None
    y: Optional[Union[StrictFloat, StrictInt]] = None
    z: Optional[Union[StrictFloat, StrictInt]] = None
    inertial_center_in_spacecraft_frame_x: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertialCenterInSpacecraftFrameX")
    inertial_center_in_spacecraft_frame_y: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertialCenterInSpacecraftFrameY")
    inertial_center_in_spacecraft_frame_z: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertialCenterInSpacecraftFrameZ")
    inertia_xx: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaXX")
    inertia_xy: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaXY")
    inertia_xz: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaXZ")
    inertia_yy: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaYY")
    inertia_yz: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaYZ")
    inertia_zz: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaZZ")
    inertia_zy: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaZY")
    inertia_zx: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaZX")
    inertia_yx: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="inertiaYX")
    thruster_axis_in_satellite_frame_x: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrusterAxisInSatelliteFrameX")
    thruster_axis_in_satellite_frame_y: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrusterAxisInSatelliteFrameY")
    thruster_axis_in_satellite_frame_z: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="thrusterAxisInSatelliteFrameZ")
    body_solar_array_faces: Optional[List[StrictStr]] = Field(default=None, alias="bodySolarArrayFaces")
    solar_array_efficiency: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayEfficiency")
    solar_array_maximum_power: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayMaximumPower")
    solar_array_surface: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArraySurface")
    solar_array_axis_in_satellite_frame_x: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayAxisInSatelliteFrameX")
    solar_array_axis_in_satellite_frame_y: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayAxisInSatelliteFrameY")
    solar_array_axis_in_satellite_frame_z: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayAxisInSatelliteFrameZ")
    solar_array_normal_in_satellite_frame_x: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayNormalInSatelliteFrameX")
    solar_array_normal_in_satellite_frame_y: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayNormalInSatelliteFrameY")
    solar_array_normal_in_satellite_frame_z: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="solarArrayNormalInSatelliteFrameZ")
    payload_pointing_axis_in_satellite_frame_x: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="payloadPointingAxisInSatelliteFrameX")
    payload_pointing_axis_in_satellite_frame_y: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="payloadPointingAxisInSatelliteFrameY")
    payload_pointing_axis_in_satellite_frame_z: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="payloadPointingAxisInSatelliteFrameZ")
    antenna_pointing_axis_in_satellite_frame_x: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="antennaPointingAxisInSatelliteFrameX")
    antenna_pointing_axis_in_satellite_frame_y: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="antennaPointingAxisInSatelliteFrameY")
    antenna_pointing_axis_in_satellite_frame_z: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="antennaPointingAxisInSatelliteFrameZ")
    spherical_cross_section: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, alias="sphericalCrossSection")
    solar_array_definition_type: Optional[StrictStr] = Field(default=None, alias="solarArrayDefinitionType")
    solar_array_type: Optional[StrictStr] = Field(default=None, alias="solarArrayType")
    type: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["x", "y", "z", "inertialCenterInSpacecraftFrameX", "inertialCenterInSpacecraftFrameY", "inertialCenterInSpacecraftFrameZ", "inertiaXX", "inertiaXY", "inertiaXZ", "inertiaYY", "inertiaYZ", "inertiaZZ", "inertiaZY", "inertiaZX", "inertiaYX", "thrusterAxisInSatelliteFrameX", "thrusterAxisInSatelliteFrameY", "thrusterAxisInSatelliteFrameZ", "bodySolarArrayFaces", "solarArrayEfficiency", "solarArrayMaximumPower", "solarArraySurface", "solarArrayAxisInSatelliteFrameX", "solarArrayAxisInSatelliteFrameY", "solarArrayAxisInSatelliteFrameZ", "solarArrayNormalInSatelliteFrameX", "solarArrayNormalInSatelliteFrameY", "solarArrayNormalInSatelliteFrameZ", "payloadPointingAxisInSatelliteFrameX", "payloadPointingAxisInSatelliteFrameY", "payloadPointingAxisInSatelliteFrameZ", "antennaPointingAxisInSatelliteFrameX", "antennaPointingAxisInSatelliteFrameY", "antennaPointingAxisInSatelliteFrameZ", "sphericalCrossSection", "solarArrayDefinitionType", "solarArrayType", "type"]

    @field_validator('body_solar_array_faces')
    def body_solar_array_faces_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(['PLUS_X', 'MINUS_X', 'PLUS_Y', 'MINUS_Y', 'PLUS_Z', 'MINUS_Z']):
                raise ValueError("each list item must be one of ('PLUS_X', 'MINUS_X', 'PLUS_Y', 'MINUS_Y', 'PLUS_Z', 'MINUS_Z')")
        return value

    @field_validator('solar_array_definition_type')
    def solar_array_definition_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['MAXIMUM_POWER', 'SURFACE', 'SURFACE_AND_POWER']):
            raise ValueError("must be one of enum values ('MAXIMUM_POWER', 'SURFACE', 'SURFACE_AND_POWER')")
        return value

    @field_validator('solar_array_type')
    def solar_array_type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['BODY', 'DEPLOYABLE_FIXED', 'DEPLOYABLE_ROTATING', 'NONE']):
            raise ValueError("must be one of enum values ('BODY', 'DEPLOYABLE_FIXED', 'DEPLOYABLE_ROTATING', 'NONE')")
        return value

    @field_validator('type')
    def type_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['SPHERE', 'BOX']):
            raise ValueError("must be one of enum values ('SPHERE', 'BOX')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SpacecraftGeometry from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SpacecraftGeometry from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "x": obj.get("x"),
            "y": obj.get("y"),
            "z": obj.get("z"),
            "inertialCenterInSpacecraftFrameX": obj.get("inertialCenterInSpacecraftFrameX"),
            "inertialCenterInSpacecraftFrameY": obj.get("inertialCenterInSpacecraftFrameY"),
            "inertialCenterInSpacecraftFrameZ": obj.get("inertialCenterInSpacecraftFrameZ"),
            "inertiaXX": obj.get("inertiaXX"),
            "inertiaXY": obj.get("inertiaXY"),
            "inertiaXZ": obj.get("inertiaXZ"),
            "inertiaYY": obj.get("inertiaYY"),
            "inertiaYZ": obj.get("inertiaYZ"),
            "inertiaZZ": obj.get("inertiaZZ"),
            "inertiaZY": obj.get("inertiaZY"),
            "inertiaZX": obj.get("inertiaZX"),
            "inertiaYX": obj.get("inertiaYX"),
            "thrusterAxisInSatelliteFrameX": obj.get("thrusterAxisInSatelliteFrameX"),
            "thrusterAxisInSatelliteFrameY": obj.get("thrusterAxisInSatelliteFrameY"),
            "thrusterAxisInSatelliteFrameZ": obj.get("thrusterAxisInSatelliteFrameZ"),
            "bodySolarArrayFaces": obj.get("bodySolarArrayFaces"),
            "solarArrayEfficiency": obj.get("solarArrayEfficiency"),
            "solarArrayMaximumPower": obj.get("solarArrayMaximumPower"),
            "solarArraySurface": obj.get("solarArraySurface"),
            "solarArrayAxisInSatelliteFrameX": obj.get("solarArrayAxisInSatelliteFrameX"),
            "solarArrayAxisInSatelliteFrameY": obj.get("solarArrayAxisInSatelliteFrameY"),
            "solarArrayAxisInSatelliteFrameZ": obj.get("solarArrayAxisInSatelliteFrameZ"),
            "solarArrayNormalInSatelliteFrameX": obj.get("solarArrayNormalInSatelliteFrameX"),
            "solarArrayNormalInSatelliteFrameY": obj.get("solarArrayNormalInSatelliteFrameY"),
            "solarArrayNormalInSatelliteFrameZ": obj.get("solarArrayNormalInSatelliteFrameZ"),
            "payloadPointingAxisInSatelliteFrameX": obj.get("payloadPointingAxisInSatelliteFrameX"),
            "payloadPointingAxisInSatelliteFrameY": obj.get("payloadPointingAxisInSatelliteFrameY"),
            "payloadPointingAxisInSatelliteFrameZ": obj.get("payloadPointingAxisInSatelliteFrameZ"),
            "antennaPointingAxisInSatelliteFrameX": obj.get("antennaPointingAxisInSatelliteFrameX"),
            "antennaPointingAxisInSatelliteFrameY": obj.get("antennaPointingAxisInSatelliteFrameY"),
            "antennaPointingAxisInSatelliteFrameZ": obj.get("antennaPointingAxisInSatelliteFrameZ"),
            "sphericalCrossSection": obj.get("sphericalCrossSection"),
            "solarArrayDefinitionType": obj.get("solarArrayDefinitionType"),
            "solarArrayType": obj.get("solarArrayType"),
            "type": obj.get("type")
        })
        return _obj





# coding: utf-8

"""
    Orbital transfer API

    Orbital transfer API

    The version of the OpenAPI document: 0.0.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from orbital_transfer.models.analytical_orbital_transfer_result import AnalyticalOrbitalTransferResult

class TestAnalyticalOrbitalTransferResult(unittest.TestCase):
    """AnalyticalOrbitalTransferResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AnalyticalOrbitalTransferResult:
        """Test AnalyticalOrbitalTransferResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AnalyticalOrbitalTransferResult`
        """
        model = AnalyticalOrbitalTransferResult()
        if include_optional:
            return AnalyticalOrbitalTransferResult(
                delta_v = 1.337,
                delta_inclination = 1.337,
                delta_semi_major_axis = 1.337,
                delta_eccentricity = 1.337,
                maneuvering_duration = 1.337,
                mission_duration = 1.337,
                thrust_duration = 1.337,
                thruster_mean_duty_cycle = 1.337,
                total_impulse = 1.337,
                used_propellant = 1.337,
                number_of_burns = 56,
                mean_burn_duration_estimation = 1.337,
                drag_perturbation_enabled = True,
                mean_atmospheric_density = 1.337,
                mean_drag = 1.337,
                mean_drag_acceleration = 1.337,
                drag_to_thrust_ratio = 1.337,
                drag_delta_v = 1.337,
                maneuver_model = '',
                errors = [
                    ''
                    ],
                warnings = [
                    ''
                    ],
                computation_date = ''
            )
        else:
            return AnalyticalOrbitalTransferResult(
        )
        """

    def testAnalyticalOrbitalTransferResult(self):
        """Test AnalyticalOrbitalTransferResult"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
